@@ -2,13 +2,11 @@
 import plugshop.utils as utils
 
 from django.contrib import admin
-from django.utils.translation import ugettext as _
-
+from django.utils.translation import ugettext_lazy as _
 
 from mptt.admin import MPTTModelAdmin
 
 from plugshop import settings
-from plugshop.utils import load_class
 from plugshop.models import *
 from plugshop.utils import is_default_model, get_model
 
@@ -28,10 +26,11 @@ class BaseProductAdmin(admin.ModelAdmin):
     list_filter = (
         'category',
     )
+    
     def changelist_view(self, request, extra_context=None):
-        context = {}
-        return super(BaseProductAdmin, self).changelist_view(request, 
-                                                        extra_context=context)
+        ctx = {}
+        return super(BaseProductAdmin, self).changelist_view(
+                                                    request, extra_context=ctx)
 
 if is_default_model('PRODUCT'):
     admin.site.register(get_model(settings.PRODUCT_MODEL), BaseProductAdmin)
@@ -51,18 +50,17 @@ class BaseCategoryAdmin(MPTTModelAdmin):
     def get_products(self, instance):
         return "<br/>".join(p.name for p in instance.products.all())
     get_products.allow_tags = True
-    get_products.short_description = _('products')
-    
-if is_default_model('CATEGORY'):
-    admin.site.register(get_model(settings.CATEGORY_MODEL), 
-                                    BaseCategoryAdmin)
+    get_products.short_description = _(u'products')
 
+if is_default_model('CATEGORY'):
+    admin.site.register(get_model(settings.CATEGORY_MODEL), BaseCategoryAdmin)
 
 
 class BaseOrderProductsInline(admin.TabularInline):
     model = get_model(settings.ORDER_PRODUCTS_MODEL)
     extra = 0
 
+
 class BaseOrderAdmin(admin.ModelAdmin):
     date_hierarchy = 'created_at'
     inlines = (
@@ -76,11 +74,12 @@ class BaseOrderAdmin(admin.ModelAdmin):
         'price_total',
         'created_at',
         'updated_at',
-        'delivered_at',
     )
     list_filter = (
         'status', 
         'created_at',
     )
+
+
 if is_default_model('ORDER'):
     admin.site.register(get_model(settings.ORDER_MODEL), BaseOrderAdmin)
