@@ -1,21 +1,22 @@
 from django import forms
-from django.utils.translation import ugettext as _
+from django.utils.translation import ugettext_lazy as _
 from django.contrib.auth.models import User
 
 from plugshop import settings
-from plugshop.utils import load_class, get_model
+from plugshop.utils import get_model
 
 PRODUCT_CLASS = get_model(settings.PRODUCT_MODEL)
 ORDER_CLASS = get_model(settings.ORDER_MODEL)
 ORDER_PRODUCTS_CLASS = get_model(settings.ORDER_PRODUCTS_MODEL)
-NAME_ERROR = _('Name is required')
-EMAIL_ERROR = _('Invalid email address')
-EMAIL_ERROR_EXISTS = _("Email address '%s' already exits, must be unique")
+NAME_ERROR = _(u'Name is required')
+EMAIL_ERROR = _(u'Invalid email address')
+EMAIL_ERROR_EXISTS = _(u"Email address '%s' already exits, must be unique")
 
 class ProductForm(forms.Form):
     product = forms.ModelChoiceField(queryset=PRODUCT_CLASS.objects)
     quantity = forms.IntegerField(required=False)
 
+
 class OrderForm(forms.ModelForm):
 
     class Meta:
@@ -25,24 +26,20 @@ class OrderForm(forms.ModelForm):
             'status',
             'created_at',
             'updated_at',
-            'delivered_at',
             'user',
             'products',
         )
 
     name = forms.CharField(required=True, error_messages={
-                                            'required': NAME_ERROR
-                                        })
+                           'required': NAME_ERROR})
     email = forms.EmailField(required=True, error_messages={
-                                            'required': EMAIL_ERROR
-                                        })
+                             'required': EMAIL_ERROR})
 
     def save(self, commit=True, **kwargs):
         cart = kwargs.get('cart')
 
         user, created = User.objects.get_or_create(
-            email = self.cleaned_data.get('email')
-        )
+                                        email=self.cleaned_data.get('email'))
         if created:
             user.username = self.cleaned_data.get('email')
             user.email = self.cleaned_data.get('email')
@@ -60,8 +57,7 @@ class OrderForm(forms.ModelForm):
                 ORDER_PRODUCTS_CLASS.objects.create(
                     product=c.product,
                     quantity=c.quantity,
-                    order=model
-                )
+                    order=model)
                 
         return model
 
